.. _api:

#############
API reference
#############

Here the reference documentation is provided for aeolus's public API.
If you are new to the package or just trying to get a feel for the
overall workflow, you are better off starting in the :ref:`examples` section of the documentation.

.. warning::

   aeolus is under active development. It is likely that some breaking changes to
   the codebase will occur in the future as aeolus is improved.

.. toctree::
   :maxdepth: 1

   calc
   core
   const
   coord
   io
   model
   plot
   region
   subset
   synthobs
